.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _tutorial-parameterize:

Parameterizing tests
====================

A single ``.pyt`` test file can generate multiple test cases, each having different parameters as defined by the :ref:`parameterize <directive-parameterize>` directive.  Variations (test cases) of the test file are generated for combinations of parameter name[s] and value[s].


.. toctree::
    :maxdepth: 1

    Getting started <parameterize.first>
    Multiple parameters <parameterize.second>
    Combining multiple parameter sets <parameterize.multi>
    Special parameter names <parameterize.special>
    Different types of parameterization <parameterize.types>
